@@ -47,7 +47,7 @@ sub CLEAR {
 }
 
 sub SCALAR {
-	scalar %{$_[0]->{hash}};
+	scalar keys %{$_[0]->{hash}};
 }
 
 1;
